==> fengoffice_1.7.5.zip: fengoffice/language/en_us/help.php <==
<?php

// Return array of langs
return array(
	'chelp pending tasks widget' => 'This widget displays your incomplete tasks. You can view only incomplete tasks assigned to you, or you can change this setting by accessing your dashboard options.',
	'chelp documents widget' => 'This widget displays the latest documents in the selected workspace.',
 	'chelp active tasks widget' => 'This widget displays your active and paused tasks.',
 	'chelp late tasks widget' => 'This widget displays your late tasks and milestones, as the ones due today, ordered by due date.',
 	'chelp calendar widget' => 'This widget displays the current week\'s events, due tasks and milestones. You can create a new event by clicking on a day.',
 	'chelp comments widget' => 'This widget displays the latest comments for objects in the current workspace.',
 	'chelp dashboard info widget' => 'This widget displays information for the current workspace, including users with access, assigned contacts, etc...',
 	'chelp emails widget' => 'This widget displays the latest emails classified in the current workspace.',
 	'chelp messages widget' => 'This widget shows the latest notes for the selected workspace.',
 	
 	'chelp active tasks panel' => 'All your active tasks are displayed below, regardless of the current workspace. This panel also offers the possibility to pause the task, continue it and set it as complete when finished.',
	'chelp general timeslots panel' => 'This panel displays timeslots directly assigned to a workspace. ',

	'chelp personal account' => 'This is your personal account.<br/>In this view you can update your profile and avatar, change your password and edit your personal preferences.',
	'chelp user account' => 'This is a user account.',
	'chelp user account admin' => 'This is a user account.<br/>Being an administrator, you may update the user\'s profile and avatar, change his or her password, and edit his or her preferences through this view.',

	'chelp reporting panel' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.',
	'chelp reporting panel manage' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.<br/>As you also have report management privileges, you can create and manage custom reports for each object type.',
	'chelp reporting panel manage admin' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.<br/>As you also have report management privileges, you can create and manage custom reports for each object type. These privileges are set for each user in the user permissions section.',

	'chelp addfile' => 'You are given the option to upload a file or a web link.<br/>
						<b> File:</b> Allows you to search and upload any document from you local hard drive.<br/>
						<b> Web link:</b> Allows you to enter the url of a web site you want to make reference to.<br/>',

 	'remove context help' => 'Remove this help message',

	'chelp tasks list welcome' => 'Welcome to the tasks panel',

	'chelp tasks list' => '<br/>You can apply one of the following filters:<br/>
							<b>Created by</b>: only display tasks created by a specific user or group <br/>
							<b>Completed by</b>: only display tasks completed by a specific user or group <br/>
							<b>Assigned to</b>: only display tasks assigned to a specific user or group <br/>
							<b>Assigned by</b>: only display tasks assigned by a specific user or group <br/>
							<b>Milestone</b>: only display tasks belonging to a specific milestone<br/>
							<b>Priority</b>: only display tasks with a specific priority (low, normal, high) <br/>
							</td>
							<td>
							<br/>You can group tasks by the following criteria (among others):<br/>
							<b>Milestone</b>: group tasks by a specific milestone <br/>
							<b>Priority</b>: group tasks by a specific priority (low, normal, high) <br/>
							<b>Workspace</b>: group tasks by a specific workspace <br/>',
	
	'help opt show' => 'Show',
	'help opt hide' => 'Hide',
	'context help messages' => 'Context help messages',
	'enable all chelp messages' => 'To enable all of the context messages closed manually',
	'enable all chelp messages click' => 'click here',
	'help manual' => 'Help Manual',
	'about us' => 'About us',
	'success enable all context help' => 'Context help re-opened successfully.',
	'success enable context help' => 'Context help enabled successfully.',
	'success disable context help' => 'Context help disabled successfully.',
	'how to purchase' => 'How to purchase',
	'how to purchase desc' => 'Information about our different plans and benefits', 
	'add ticket' => 'Add a new support ticket',
	'add ticket desc' => "To get personalized help about Feng Office",	
	
); // array

?>

==> fengoffice_2.0.0.zip: fengoffice/language/en_us/help.php <==
<?php

// Return array of langs
return array(
	'chelp pending tasks widget' => 'This widget displays your incomplete tasks. You can view only incomplete tasks assigned to you, or you can change this setting by accessing your dashboard options.',
	'chelp documents widget' => 'This widget displays the latest documents in the selected workspace.',
 	'chelp active tasks widget' => 'This widget displays your active and paused tasks.',
 	'chelp late tasks widget' => 'This widget displays your late tasks and milestones, as the ones due today, ordered by due date.',
 	'chelp calendar widget' => 'This widget displays the current week\'s events, due tasks and milestones. You can create a new event by clicking on a day.',
 	'chelp comments widget' => 'This widget displays the latest comments for objects in the current workspace.',
 	'chelp dashboard info widget' => 'This widget displays information for the current workspace, including users with access, assigned contacts, etc...',
 	'chelp emails widget' => 'This widget displays the latest emails classified in the current workspace.',
 	'chelp messages widget' => 'This widget shows the latest notes',
 	
 	'chelp active tasks panel' => 'All your active tasks are displayed below, regardless of the current workspace. This panel also offers the possibility to pause the task, continue it and set it as complete when finished.',
	'chelp general timeslots panel' => 'This panel displays timeslots directly assigned to a workspace. ',

	'chelp personal account' => 'This is your personal account.<br/>In this view you can update your profile and avatar, change your password and edit your personal preferences.',
	'chelp user account' => 'This is a user account.',
	'chelp user account admin' => 'This is a user account.<br/>Being an administrator, you may update the user\'s profile and avatar, change his or her password, and edit his or her preferences through this view.',

	'chelp reporting panel' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.',
	'chelp reporting panel manage' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.<br/>As you also have report management privileges, you can create and manage custom reports for each object type.',
	'chelp reporting panel manage admin' => '<b>Welcome to the Reports panel</b><br/>You can customize reports from the different objects located in the left panel.<br/>As you also have report management privileges, you can create and manage custom reports for each object type. These privileges are set for each user in the user permissions section.',

	'chelp addfile' => 'You are given the option to upload a file or a web link.<br/>
						<b> File:</b> Allows you to search and upload any document from you local hard drive.<br/>
						<b> Web link:</b> Allows you to enter the url of a web site you want to make reference to.<br/>',

 	'remove context help' => 'Remove this help message',

	'chelp tasks list welcome' => 'Welcome to the tasks panel',

	'chelp tasks list' => '<br/>You can apply one of the following filters:<br/>
							<b>Created by</b>: only display tasks created by a specific user or group <br/>
							<b>Completed by</b>: only display tasks completed by a specific user or group <br/>
							<b>Assigned to</b>: only display tasks assigned to a specific user or group <br/>
							<b>Assigned by</b>: only display tasks assigned by a specific user or group <br/>
							<b>Milestone</b>: only display tasks belonging to a specific milestone<br/>
							<b>Priority</b>: only display tasks with a specific priority (low, normal, high) <br/>
							</td>
							<td>
							<br/>You can group tasks by the following criteria (among others):<br/>
							<b>Milestone</b>: group tasks by a specific milestone <br/>
							<b>Priority</b>: group tasks by a specific priority (low, normal, high) <br/>
							<b>Workspace</b>: group tasks by a specific workspace <br/>',
	
	'help opt show' => 'Show',
	'help opt hide' => 'Hide',
	'context help messages' => 'Context help messages',
	'enable all chelp messages' => 'To enable all of the context messages closed manually',
	'enable all chelp messages click' => 'click here',
	'help manual' => 'Help Manual',
	'about us' => 'About us',
	'success enable all context help' => 'Context help re-opened successfully.',
	'success enable context help' => 'Context help enabled successfully.',
	'success disable context help' => 'Context help disabled successfully.',
	'how to purchase' => 'How to purchase',
	'how to purchase desc' => 'Information about our different plans and benefits', 
	'add ticket' => 'Add a new support ticket',
	'add ticket desc' => "To get personalized help about Feng Office",	
	
); // array

?>
